@@ -14,13 +14,13 @@ from pieberry_validators import *
 from pieberry_events import *
 from pieberry_worker import *
 from pieberry_output import *
+from pieberry_pybtex import *
 
 DEFAULT_SIZE = wx.Size(720, 480) #main window size
 TITLE = 'PieBerry Library Assistant'
 BUTTON_SIZE = wx.Size(100, 36) #size of main control buttons
 smallspace = (10, 10)
 tinyspace = (5, 5)
-PY2EXE = False
 
 # Button definitions
 ID_START = wx.NewId()
@@ -38,6 +38,15 @@ class UiTimer(wx.Timer):
         self._f.onMouseUpdateList()
         self._f.onPrefetchTag(self._last_iteration)
 
+class SpinnyTimer(wx.Timer):
+    def __init__(self, parent, *args, **kwargs):
+        wx.Timer.__init__(self, *args, **kwargs)
+        self._f = parent
+
+    def Notify(self):
+        self._f.spinnerTick()
+        
+
 class pieMainWindow(wx.Frame):
     '''Main window class for PieBerry'''
     _BUTTON_SIZE = wx.Size(100, 50)
@@ -59,6 +68,7 @@ class pieMainWindow(wx.Frame):
         self.outputList.Bind(wx.EVT_LEAVE_WINDOW, self.onMouseExitList)
         self.uitimer = UiTimer(self)
         self.uitimer.Start(1000)
+        self.spinTimer = None
         self.mouse_last_pos = wx.Point(0,0)
         self.url_text_last_changed = time.time()
         self.tipwindow = None # tooltip for bib data
@@ -82,10 +92,11 @@ class pieMainWindow(wx.Frame):
         #     'month': 'January',
         #     'howpublished': 'Mungdinugn',
         #     'annote': 'notey',
-        #     'ancillary_downloadtime': time.localtime(),
-        #     'ancillary_creationtime': time.localtime(),
-        #     'ancillary_outfilename': 'C:noodles',
-        #     'ancillary_locofdoc': 'http://www.hell.no',
+        #     'download_time': time.localtime(),
+        #     'creation_date': time.localtime(),
+        #     'final_fn': 'C:noodles',
+        #     'pdflink': 'http://www.hell.no',
+        #     'url': 'http://www.themong.spo.nn/',
         #     'exclude': True,
         #     'internal_author': 'Jon Hoo',
         #     'internal_title': 'Noh Wai'
@@ -93,7 +104,7 @@ class pieMainWindow(wx.Frame):
         # spoof_data_id = wx.NewId()
         # spoofbib = {}
         # spoofbib[spoof_data_id] = spoofdata
-        # wx.PostEvent(self, pieUpdateEvent('success', 'Success', cite="%s (%s). %s" % (spoofdata['author'], spoofdata['year'], spoofdata['title']), href=spoofdata['ancillary_locofdoc'], data_id=spoof_data_id, updatelast=False))
+        # wx.PostEvent(self, pieUpdateEvent('success', 'Success', cite="%s (%s). %s" % (spoofdata['author'], spoofdata['year'], spoofdata['title']), href=spoofdata['pdflink'], data_id=spoof_data_id, updatelast=False))
         # self.allData.update(spoofbib)
         # self.sc_auth = "Spoof author"
         # self.menu_discard.Enable(True)
@@ -102,10 +113,7 @@ class pieMainWindow(wx.Frame):
 
     def _do_layout(self):
         _icon = wx.EmptyIcon()
-        if PY2EXE:
-            _icon.CopyFromBitmap(wx.Bitmap('pie_16.png'))
-        else:
-            _icon.CopyFromBitmap(wx.Bitmap(os.path.join(GetAppdir(), 'pie_16.png')))
+        _icon.CopyFromBitmap(wx.Bitmap(os.path.join(IMGDIR, 'pie_16.png')))
         self.SetIcon(_icon)
 
         rawlist = os.listdir(config.get('PBoptions', 'workingdir'))
@@ -114,6 +122,7 @@ class pieMainWindow(wx.Frame):
 
         menuBar = wx.MenuBar()
         fileMenu = wx.Menu()
+        toolMenu = wx.Menu()
         self.menu_savebibs = wx.MenuItem(fileMenu, -1, '&Save Bibliography Changes [%s]\tCtrl-s' % os.path.basename(config.get('PBoptions', 'default_bibliography')), 'Save')
         self.menu_savebibs.SetBitmap(wx.ArtProvider.GetBitmap(wx.ART_FILE_SAVE, wx.ART_MENU, (16, 16)))
         self.menu_discard = wx.MenuItem(fileMenu, -1, '&Discard Bibliography Changes', 'Discard')
@@ -121,12 +130,20 @@ class pieMainWindow(wx.Frame):
         self.menu_quit.SetBitmap(wx.ArtProvider.GetBitmap(wx.ART_QUIT, wx.ART_MENU))
         self.menu_config = wx.MenuItem(fileMenu, -1, 'S&ettings', 'Config')
         self.menu_about = wx.MenuItem(fileMenu, -1, '&About', 'About')
+        self.menu_pageref = wx.MenuItem(toolMenu, -1, 'Create &reference for top-level page', 'Reference')
         fileMenu.AppendItem(self.menu_savebibs)
         fileMenu.AppendItem(self.menu_discard)
         fileMenu.AppendItem(self.menu_config)
         fileMenu.AppendItem(self.menu_about)
         fileMenu.AppendItem(self.menu_quit)
+        toolMenu.AppendItem(self.menu_pageref)
+        # if PYBTEX:
+        self.menu_find = wx.MenuItem(toolMenu, -1, '&Find items in bibliography\tCtrl-f', 'Find')
+        self.menu_find.SetBitmap(wx.ArtProvider.GetBitmap(wx.ART_FIND, wx.ART_MENU))
+        toolMenu.AppendItem(self.menu_find)
+        self.Bind(wx.EVT_MENU, self.onFind, self.menu_find)
         menuBar.Append(fileMenu, '&File')
+        menuBar.Append(toolMenu, '&Tools')
         self.SetMenuBar(menuBar)
         self.SetAutoLayout(True)
         self.Bind(wx.EVT_MENU, self.onSaveBibs, self.menu_savebibs)
@@ -134,6 +151,7 @@ class pieMainWindow(wx.Frame):
         self.Bind(wx.EVT_MENU, self.onConfig, self.menu_config)
         self.Bind(wx.EVT_MENU, self.onAbout, self.menu_about)
         self.Bind(wx.EVT_MENU, self.onDiscard, self.menu_discard)
+        self.Bind(wx.EVT_MENU, self.onPageReference, self.menu_pageref)
         self.menu_savebibs.Enable(False)
         self.menu_discard.Enable(False)
 
@@ -183,24 +201,24 @@ class pieMainWindow(wx.Frame):
         self.outputList = wx.ListCtrl(panel1, -1, style=wx.LC_REPORT|wx.EXPAND)
 
         self.iList = wx.ImageList(16, 16)
-        if PY2EXE: #py2exe has a problem looking elsewhere for files
-            self.iList.Add(wx.Bitmap('ic_blueball16.png'))
-            self.iList.Add(wx.Bitmap('ic_redsquare16.png'))
-            self.iList.Add(wx.Bitmap('ic_yellowex16.png'))
-            self.iList.Add(wx.Bitmap('ic_greensquare16.png'))
-            self.iList.Add(wx.Bitmap('ic_greentick16.png'))
-            self.iList.Add(wx.Bitmap('ic_blueex16.png'))
-        else:
-            self.iList.Add(wx.Bitmap(os.path.join(GetAppdir(), 'ic_blueball16.png')))
-            self.iList.Add(wx.Bitmap(os.path.join(GetAppdir(), 'ic_redsquare16.png')))
-            self.iList.Add(wx.Bitmap(os.path.join(GetAppdir(), 'ic_yellowex16.png')))
-            self.iList.Add(wx.Bitmap(os.path.join(GetAppdir(), 'ic_greensquare16.png')))
-            self.iList.Add(wx.Bitmap(os.path.join(GetAppdir(), 'ic_greentick16.png')))
-            self.iList.Add(wx.Bitmap(os.path.join(GetAppdir(), 'ic_blueex16.png')))
+        self.iList.Add(wx.Bitmap(os.path.join(IMGDIR, 'ic_blueball16.png')))
+        self.iList.Add(wx.Bitmap(os.path.join(IMGDIR, 'ic_redsquare16.png')))
+        self.iList.Add(wx.Bitmap(os.path.join(IMGDIR, 'ic_yellowex16.png')))
+        self.iList.Add(wx.Bitmap(os.path.join(IMGDIR, 'ic_greensquare16.png')))
+        self.iList.Add(wx.Bitmap(os.path.join(IMGDIR, 'ic_greentick16.png')))
+        self.iList.Add(wx.Bitmap(os.path.join(IMGDIR, 'ic_blueex16.png')))
+        self.iList.Add(wx.Bitmap(os.path.join(IMGDIR, 'al00.png')))
+        self.iList.Add(wx.Bitmap(os.path.join(IMGDIR, 'al01.png')))
+        self.iList.Add(wx.Bitmap(os.path.join(IMGDIR, 'al02.png')))
+        self.iList.Add(wx.Bitmap(os.path.join(IMGDIR, 'al03.png')))
+        self.iList.Add(wx.Bitmap(os.path.join(IMGDIR, 'al04.png')))
+        self.iList.Add(wx.Bitmap(os.path.join(IMGDIR, 'al05.png')))
 
+        self.spinnerstate = -1
         self.listcols = ('', 'Document', 'Link')
         self.widthcols = (150, 380, 300)
         self.msgtypes = {
+            'spin': 'spin',
             'blank': None,
             'success': 0,
             'fail': 1,
@@ -222,7 +240,6 @@ class pieMainWindow(wx.Frame):
         sizer0.SetFlexibleDirection(wx.BOTH)
         sizer1 = wx.BoxSizer(wx.VERTICAL)
 
-
         sizerA.Add(lburl, 1, wx.EXPAND|wx.ALL, 3)
         sizerA.Add(self.pasteButton, 0, wx.ALL, 3)
         sizer0.Add(sizerA, 1, wx.EXPAND)
@@ -275,9 +292,15 @@ class pieMainWindow(wx.Frame):
         else: 
             thisidx = idx
         if msgtype == 'blank':
+            if self.spinTimer: self.spinnerStop()
             nexidx = self.outputList.InsertStringItem(thisidx, msg)
         else:
-            nexidx = self.outputList.InsertImageStringItem(thisidx, msg, self.msgtypes[msgtype])
+            if msgtype == 'spin':
+                nexidx = self.outputList.InsertImageStringItem(thisidx, msg, 6)
+                self.spinnerStart(nexidx)
+            else:
+                if self.spinTimer: self.spinnerStop()
+                nexidx = self.outputList.InsertImageStringItem(thisidx, msg, self.msgtypes[msgtype])
         # set reference to store of bibliography data against the item
         if not data_id is None:
             self.outputList.SetItemData(nexidx, data_id)
@@ -289,6 +312,43 @@ class pieMainWindow(wx.Frame):
         self.outputList.EnsureVisible(nexidx) # scroll to here
         return nexidx
 
+    def onFind(self, evt):
+        self.suppress_tipwindow = True
+        if tuple(self.allData.keys()) != tuple(self.savedDataKeys): #check whether we've saved all this to the .bib file before exiting
+            dia = wx.MessageDialog(self, 'You have unsaved bibliography data for downloaded files.\nSave these to your master bibliography file before exiting?', 'Unsaved items', style=wx.YES|wx.NO|wx.CANCEL)
+            ans = dia.ShowModal()
+            if ans == wx.ID_CANCEL: return
+            if ans == wx.ID_YES: self.onSaveBibs()
+        tedia = wx.TextEntryDialog(self, 'Find items (Syntax: "field1==term1;term2, field1==term3 ...)', 'Find items in bibliography matching:', defaultValue='author==')
+        tedo = tedia.ShowModal()
+        self.suppress_tipwindow = False
+        if tedo == wx.ID_CANCEL:
+            return
+        searchphrase = tedia.GetValue()
+        if len(searchphrase.strip()) == 0:
+            return
+        self.outputList.DeleteAllItems()
+        self.allData = {}
+        self.savedDataKeys = []
+        # from pieberry_pybtex import get_top_search_results
+        res = get_top_search_results(searchphrase)
+        for bibdata in res:
+            newid = wx.NewId()
+            print newid
+            self.allData[newid] = bibdata
+            wx.PostEvent(
+                self, 
+                pieUpdateEvent(
+                    'success', 
+                    'Found', 
+                    cite="%s (%s). %s" % (bibdata['author'], bibdata['year'], bibdata['title']), 
+                    href=bibdata['pdflink'], 
+                    data_id=newid, 
+                    updatelast=False))
+        self.savedDataKeys = self.allData.keys()
+        self.menu_savebibs.Enable(False)
+        self.menu_discard.Enable(False)
+
     def onPasteButton(self, evt):
         if not wx.TheClipboard.IsOpened():
             wx.TheClipboard.Open()
@@ -301,7 +361,7 @@ class pieMainWindow(wx.Frame):
     def onAbout(self, evt):
         info = wx.AboutDialogInfo()
         info.AddDeveloper('Raif Sarcich')
-        info.SetVersion('1.5-1')
+        info.SetVersion('1.6-1')
         info.SetCopyright('(c) 2010 Raif Sarcich et. al.')
         info.SetLicence('''This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -318,10 +378,7 @@ class pieMainWindow(wx.Frame):
         info.SetDescription('A program to download pdf documents from public websites, and catalogue them in BibTeX format')
         info.SetName('Pieberry (...for your library)')
         _icon = wx.EmptyIcon()
-        if PY2EXE:
-            _icon.CopyFromBitmap(wx.Bitmap('pie_48.png'))
-        else:
-            _icon.CopyFromBitmap(wx.Bitmap(os.path.join(GetAppdir(), 'pie_48.png')))
+        _icon.CopyFromBitmap(wx.Bitmap(os.path.join(IMGDIR, 'pie_48.png')))
         info.SetIcon(_icon)
         wx.AboutBox(info)
 
@@ -403,6 +460,7 @@ class pieMainWindow(wx.Frame):
         self.list_item_clicked = right_click_context = evt.GetIndex()
         ### 2. Launcher creates wxMenu. ###
         menu = wx.Menu()
+        copyMenu = wx.Menu()
         it_idx = self.outputList.GetItemData(self.list_item_clicked)
         if self.allData.has_key(it_idx):
             rcm_opendoc = wx.MenuItem(menu, 0, 'Open document')
@@ -417,6 +475,22 @@ class pieMainWindow(wx.Frame):
             rcm_deletedoc.SetBitmap(wx.ArtProvider.GetBitmap(wx.ART_DELETE, wx.ART_MENU))
             menu.AppendItem(rcm_deletedoc)
             wx.EVT_MENU(menu, 2, self.onDelete)
+            # special functionality from pybtex
+            if self.allData[it_idx].has_key('bibtex_key'):
+                rcm_copybibkey = wx.MenuItem(copyMenu, 8, 'Copy BibTeX key to clipboard')
+                rcm_copybibkey.SetBitmap(wx.ArtProvider.GetBitmap(wx.ART_COPY, wx.ART_MENU))
+                copyMenu.AppendItem(rcm_copybibkey)
+                self.Bind(wx.EVT_MENU, self.onCopyBibtexKey, rcm_copybibkey)
+        # if PYBTEX:
+            rcm_copy_citation = wx.MenuItem(copyMenu, 6, 'Copy citation to clipboard (html)')
+            rcm_copy_citation.SetBitmap(wx.ArtProvider.GetBitmap(wx.ART_COPY, wx.ART_MENU))
+            copyMenu.AppendItem(rcm_copy_citation)
+            self.Bind(wx.EVT_MENU, self.onCopyCitation, rcm_copy_citation)
+            rcm_copy_citation_plain = wx.MenuItem(copyMenu, 9, 'Copy citation to clipboard (text)')
+            rcm_copy_citation_plain.SetBitmap(wx.ArtProvider.GetBitmap(wx.ART_COPY, wx.ART_MENU))
+            copyMenu.AppendItem(rcm_copy_citation_plain)
+            self.Bind(wx.EVT_MENU, self.onCopyCitationPlain, rcm_copy_citation_plain)
+
         if self.allData.has_key(it_idx) and not it_idx in self.savedDataKeys:
             menu.Append(3, 'Edit bibliography entry')
             wx.EVT_MENU(menu, 3, self.onMenuEditBibEntry)
@@ -427,10 +501,11 @@ class pieMainWindow(wx.Frame):
             wx.EVT_MENU(menu, 4, self.onMenuToggleExclude)
         item = self.outputList.GetItem(self.list_item_clicked, 2)
         if len(item.GetText()) > 0:
-            rcm_copyurl = wx.MenuItem(menu, 5, 'Copy Web Url to Clipboard')
+            rcm_copyurl = wx.MenuItem(copyMenu, 5, 'Copy Web Url to Clipboard')
             rcm_copyurl.SetBitmap(wx.ArtProvider.GetBitmap(wx.ART_COPY, wx.ART_MENU))
-            menu.AppendItem(rcm_copyurl)
+            copyMenu.AppendItem(rcm_copyurl)
             self.Bind(wx.EVT_MENU, self.onMenuCopyUrl, rcm_copyurl)
+        menu.AppendMenu(9, 'Copy ...', copyMenu)
         # menu.Append(5, 'Debug: item data')
         # wx.EVT_MENU(menu, 5, self.onMenuDebugData)
         ### 5. Launcher displays menu with call to PopupMenu, invoked on the source component, passing event's GetPoint. ###
@@ -446,7 +521,54 @@ class pieMainWindow(wx.Frame):
         else:
             self.allData[data_id]['exclude'] = True
             self.outputList.SetItemImage(self.list_item_clicked, self.msgtypes['exclude'])
+
+    def onCopyBibtexKey(self, evt):
+        data_id = self.outputList.GetItemData(self.list_item_clicked)
+        if self.allData[data_id].has_key('bibtex_key'):
+            clipdata = wx.TextDataObject()
+            clipdata.SetText(self.allData[data_id]['bibtex_key'])
+            wx.TheClipboard.Open()
+            wx.TheClipboard.SetData(clipdata)
+            wx.TheClipboard.Close()
         
+    def onCopyCitationPlain(self, evt):
+        data_id = self.outputList.GetItemData(self.list_item_clicked)
+        pybobj = pieberry_to_pybtex(self.allData[data_id])
+        citetext = get_formatted_citation(pybobj, format='plaintext')
+        clipdata = wx.TextDataObject()
+        clipdata.SetText(citetext)
+        wx.TheClipboard.Open()
+        wx.TheClipboard.SetData(clipdata)
+        wx.TheClipboard.Close()
+        if PYNOTIFY:
+            import pynotify
+            n = pynotify.Notification("Citation", citetext, os.path.join(IMGDIR, 'pie_48.png'))
+            n.show()
+
+    def onCopyCitation(self, evt):
+        data_id = self.outputList.GetItemData(self.list_item_clicked)
+        # from pieberry_pybtex import get_formatted_citation_html
+        pybobj = pieberry_to_pybtex(self.allData[data_id])
+        if sys.platform == 'win32':
+            from pieberry_htmldataobject import HTMLDataObject
+            citetext = get_formatted_citation(pybobj, format='html')
+            clipdata = HTMLDataObject()
+            clipdata.SetValue(citetext)
+        else:
+            citetext = get_formatted_citation(pybobj, format='html')
+            clipdata = wx.TextDataObject()
+            clipdata.SetText(citetext)
+            fmt = wx.DataFormat(wx.DF_INVALID)
+            fmt.SetId('text/html')
+            clipdata.SetFormat(fmt)
+
+        wx.TheClipboard.Open()
+        wx.TheClipboard.SetData(clipdata)
+        wx.TheClipboard.Close()
+        if PYNOTIFY:
+            import pynotify
+            n = pynotify.Notification("Citation", get_formatted_citation(pybobj, format='plaintext'), os.path.join(IMGDIR, 'pie_48.png'))
+            n.show()
 
     def onListDoubleClick(self, evt):
         if evt.GetIndex() == -1: return
@@ -466,24 +588,24 @@ class pieMainWindow(wx.Frame):
         data_id = self.outputList.GetItemData(self.list_item_clicked)
         if self.allData.has_key(data_id):
             if sys.platform == 'linux2':
-                subprocess.call(('xdg-open', self.allData[data_id]['ancillary_outfilename']))
+                subprocess.call(('xdg-open', self.allData[data_id]['final_fn']))
             elif sys.platform == 'win32':
-                os.startfile(self.allData[data_id]['ancillary_outfilename'])
+                os.startfile(self.allData[data_id]['final_fn'])
 
     def onMenuOpenDocumentFolder(self, evt):
         data_id = self.outputList.GetItemData(self.list_item_clicked)
         if sys.platform == 'linux2':
-            subprocess.call(('xdg-open', os.path.dirname(self.allData[data_id]['ancillary_outfilename'])))
+            subprocess.call(('xdg-open', os.path.dirname(self.allData[data_id]['final_fn'])))
         elif sys.platform == 'win32':
-            os.startfile(os.path.dirname(self.allData[data_id]['ancillary_outfilename']))
+            os.startfile(os.path.dirname(self.allData[data_id]['final_fn']))
         elif sys.platform == 'darwin':
-            subprocess.call(('open', os.path.dirname(self.allData[data_id]['ancillary_outfilename'])))
+            subprocess.call(('open', os.path.dirname(self.allData[data_id]['final_fn'])))
 
     def onMenuCopyUrl(self, evt):
         '''copy the downloaded file's URL to the clipboard'''
         item = self.outputList.GetItem(self.list_item_clicked, 2)
-        clipdata = wx.TextDataObject()
-        clipdata.SetText(item.GetText())
+        clipdata = wx.URLDataObject()
+        clipdata.SetURL(item.GetText())
         wx.TheClipboard.Open()
         wx.TheClipboard.SetData(clipdata)
         wx.TheClipboard.Close()
@@ -503,7 +625,6 @@ class pieMainWindow(wx.Frame):
                 self.outputList.SetItemText(self.list_item_clicked, 'Updated')
                 self.outputList.SetItemImage(self.list_item_clicked, self.msgtypes['pass'])
                 self.outputList.SetStringItem(self.list_item_clicked, 1, "%s (%s). %s" % (self.allData[idx]['author'].strip('{} '), self.allData[idx]['year'], self.allData[idx]['title']))
-                # self.outputList.SetStringItem(self.list_item_clicked, 2, self.allData['ancillary_outfilename'])
             dia.Destroy()
             self.suppress_tipwindow = False
         else: print 'Tried to edit non-entry entry'
@@ -553,6 +674,29 @@ class pieMainWindow(wx.Frame):
             self.scanButton.Disable()
             self.worker = pieWorkerThread(self, scrapedata, scrapecommands)
 
+    def onPageReference(self, evt):
+        '''Create a reference for the url itself, rather than pdfs it contains'''
+        if self.urlField.GetValidator().Validate():
+            bibdata = {}
+            bibdata['author'] = self.authorField.GetValue()
+            bibdata['title'] = self.tagField.GetValue()
+            bibdata['url'] = self.urlField.GetValue()
+            bibdata['howpublished'] = 'On the web'
+            bibdata['year'] = unicode(time.strftime("%Y"))
+            bibdata['month'] = unicode(time.strftime("%B"))
+            bibdata['creation_date'] = time.localtime()
+            bibdata['download_time'] = time.localtime()
+            bibdata['final_fn'] = ''
+            bibdata['annote'] = bibdata['note'] = ''
+            bibdata['exclude'] = False
+            bibdata['internal_author'] = ''
+            bibdata['internal_title'] = ''
+            data_idx = wx.NewId()
+            self.allData[data_idx] = bibdata
+            wx.PostEvent(self, pieUpdateEvent('success', 'Success', cite="%s (%s). %s" % (bibdata['author'], bibdata['year'], bibdata['title']), href=bibdata['url'], data_id=data_idx, updatelast=False))
+            self.menu_savebibs.Enable(True)
+            self.menu_discard.Enable(True)
+
     def onStop(self, evt):
         if self.worker:
             print "Aborting..."
@@ -563,9 +707,8 @@ class pieMainWindow(wx.Frame):
         print 'savebibs'
         savedata = ''
         saved_item_keys = []
-        print self.allData
         try:
-            bibwriter = pieBibtexWriter()
+            bibwriter = pieAllWriter()
             for key, value in self.allData.items():
                 if not key in self.savedDataKeys:
                     # ensure author is treated as correct type (corp/person)
@@ -576,7 +719,7 @@ class pieMainWindow(wx.Frame):
                         else:
                             bibentry['corporate_author'] = False
                     bibwriter.addEntry(bibentry)
-                    print 'adding entry %s' % bibentry['title']
+                    # print 'adding entry %s' % bibentry['title']
                     saved_item_keys.append(key)
             bibwriter.write()
 
@@ -595,6 +738,7 @@ class pieMainWindow(wx.Frame):
             self.menu_discard.Enable(False)
             self.SetTitle(TITLE)
         except Exception:
+            traceback.print_exc()
             wx.MessageBox(traceback.format_exc())
 
     def onDiscard(self, evt=1):
@@ -618,11 +762,11 @@ class pieMainWindow(wx.Frame):
     def onDelete(self, evt):
         idx = self.outputList.GetItemData(self.list_item_clicked)
         delfileinfo = self.allData[idx]
-        dia = wx.MessageDialog(self, "Delete file %s" % delfileinfo['ancillary_outfilename'], "Delete file", style=wx.YES_NO|wx.ICON_EXCLAMATION)
+        dia = wx.MessageDialog(self, "Delete file %s" % delfileinfo['final_fn'], "Delete file", style=wx.YES_NO|wx.ICON_EXCLAMATION)
         ans = dia.ShowModal()
         if ans == wx.ID_YES:
             try:
-                os.remove(delfileinfo['ancillary_outfilename'])
+                os.remove(delfileinfo['final_fn'])
                 self.outputList.SetItemImage(self.list_item_clicked, self.msgtypes['fail'])
                 self.outputList.SetItemText(self.list_item_clicked, 'Deleted')
                 self.allData.pop(idx)
@@ -644,8 +788,8 @@ class pieMainWindow(wx.Frame):
                 writer = pieBibtexWriter()
                 for idx in self.lastDataKeys:
                     bibentry = self.allData[idx]
-                    if bibentry['author'] == self.sc_auth:
-                        bibentry['corporate_author'] = self.corpAuthorCb.IsChecked()
+                    # if bibentry['author'] == self.sc_auth:
+                    #     bibentry['corporate_author'] = self.corpAuthorCb.IsChecked()
                     writer.addEntry(bibentry)
                 writer.setLocation(os.path.join(config.get('PBoptions', 'workingdir'), self.sc_auth, self.sc_tag, '%s_bibliography.bib' % time.strftime('%Y%m%d-%H%M')))
                 writer.write()
@@ -668,6 +812,25 @@ class pieMainWindow(wx.Frame):
             self.menu_savebibs.SetItemLabel('&Save Bibliography Data [%s]\tCtrl-s' % os.path.basename(config.get('PBoptions', 'default_bibliography')))
         self.suppress_tipwindow = False
 
+    def spinnerStart(self, list_item):
+        '''start a spinning icon to indicate download'''
+        self.spin_list_item = list_item
+        self.spinTimer = SpinnyTimer(self)
+        self.spinTimer.Start(200)
+
+    def spinnerTick(self):
+        '''progress through the icon animation'''
+        if self.spinnerstate == 5:
+            self.spinnerstate = -1
+        self.spinnerstate += 1
+        sli = self.spinnerstate + 6
+        self.outputList.SetItemImage(self.spin_list_item, sli)
+        
+    def spinnerStop(self):
+        self.spinTimer.Stop()
+        self.spinTimer.Destroy()
+        self.spinTimer = None
+
 class pieNewConfigDialog(pieConfigDialog):
     def __init__(self, config, configfile, *args, **kwargs):
         pieConfigDialog.__init__(self, *args, **kwargs)
@@ -675,10 +838,15 @@ class pieNewConfigDialog(pieConfigDialog):
         self._configfile = configfile
         self.workDirCtrl.SetValue(self._config.get('PBoptions', 'workingdir'))
         self.mainBibCtrl.SetValue(self._config.get('PBoptions', 'default_bibliography'))
+        self.tsvBibCb.SetValue(self._config.getboolean('PBoptions', 'export_tsv'))
+        self.defaultEntryTypeChoice.SetSelection(self._config.getint('PBoptions', 'default_bibtex_entry_style'))
 
     def onOk(self, evt):
         self._config.set('PBoptions', 'workingdir', self.workDirCtrl.GetValue())
         self._config.set('PBoptions', 'default_bibliography', self.mainBibCtrl.GetValue())
+        self._config.set('PBoptions', 'default_bibtex_entry_style', self.defaultEntryTypeChoice.GetSelection())
+        self._config.set('PBoptions', 'default_bibtex_entry_type', ENTRY_TYPE_KEYS[self.defaultEntryTypeChoice.GetSelection()])
+        self._config.set('PBoptions', 'export_tsv', unicode(self.tsvBibCb.GetValue()))
         self._config.write(open(self._configfile, 'w'))
         self.EndModal(wx.ID_OK)
 
@@ -709,7 +877,12 @@ class pieNewBibEditDialog(pieBibEditDialog):
         self.keyCtrl.Enable(False)
         self.keyCtrl.Bind(wx.EVT_TEXT, self.onFieldValidate)
         self.keyAutoCb.Bind(wx.EVT_CHECKBOX, self.onKeygenToggle)
-        self.authorIsCorporateCb.Set3StateValue(wx.CHK_UNDETERMINED)
+        if not bibdata.has_key('corporate_author'):
+            self.authorIsCorporateCb.Set3StateValue(wx.CHK_UNDETERMINED)
+        elif bibdata['corporate_author'] == True:
+            self.authorIsCorporateCb.Set3StateValue(wx.CHK_CHECKED)
+        else:
+            self.authorIsCorporateCb.Set3StateValue(wx.CHK_UNCHECKED)
         self.authorCtrl.SetValue(bibdata['author'])
         self.authorCtrl.Bind(wx.EVT_TEXT_ENTER, self.onOk)
         self.authorCtrl.Bind(wx.EVT_TEXT, self.onFieldValidate)
@@ -726,7 +899,7 @@ class pieNewBibEditDialog(pieBibEditDialog):
         self.noteCtrl.Bind(wx.EVT_TEXT, self.onFieldValidate)
         self.annoteCtrl.SetValue(bibdata['annote'])
         self.annoteCtrl.Bind(wx.EVT_TEXT, self.onFieldValidate)
-        t = wx.DateTimeFromTimeT(time.mktime(bibdata['ancillary_creationtime']))
+        t = wx.DateTimeFromTimeT(time.mktime(bibdata['creation_date']))
         self.datePicker.SetValue(t)
         self.authorCtrl.SetFocus()
 
@@ -748,8 +921,8 @@ class pieNewBibEditDialog(pieBibEditDialog):
         self._bibdata['note'] = self.noteCtrl.GetValue()
         newdate = wxdate2pydate(self.datePicker.GetValue())
         self._bibdata['year'] = unicode(newdate.year)
-        self._bibdata['ancillary_creationtime'] = newdate.timetuple()
-        self._bibdata['month'] = time.strftime('%B', self._bibdata['ancillary_creationtime'])
+        self._bibdata['creation_date'] = newdate.timetuple()
+        self._bibdata['month'] = time.strftime('%B', self._bibdata['creation_date'])
         if not self.keyAutoCb.IsChecked():
             self._bibdata['bibtex_key'] = self.keyCtrl.GetValue()
         corpcb = self.authorIsCorporateCb.Get3StateValue()
