@@ -91,6 +91,7 @@ def snarf_pdfs(notify_window, html, url):
     head_re = re.compile('[hH][1-7]')
     sub_re = re.compile('[Ss]ubmission')
     retlist = []
+    all_are_submissions = ('ubmissions' in readup.title.string)
     for link in pdflinks:
         ret = {
             'pdflink': '',
@@ -111,6 +112,8 @@ def snarf_pdfs(notify_window, html, url):
         if head_h:
             if sub_re.search(head_h.text):
                 ret['pdflink_context'] = 'submissions'
+        if all_are_submissions:
+             ret['pdflink_context'] = 'submissions'
         # Finally assign relevant link
         # try to work out if the link is already quoted text or not
         if "%" in  link['href'].encode('utf-8'):
@@ -349,41 +352,56 @@ def gen_title_and_docname(pdfinfo, behaviour):
 
 #     return thebib
 
-def autogen_bibtex_key(bibdict):
-    keytitlecompact = string.join([i[:3] for i in string.split(bibdict['title'].encode("utf-8").translate(string.maketrans("",""), string.punctuation)) if len(i) > 3], '') #ouch ... this compacts the first three letters of each word in the title together, to make a dependably unique key
-    keyauthorcompact = string.join([i[:1] for i in string.split(bibdict['author'].encode("utf-8").translate(string.maketrans("",""), string.punctuation)) if len(i) > 3], '') #same for authors, but just initials
-    key = "%s%s_%s" % (
-        keyauthorcompact,
-        bibdict['year'].encode('utf-8'), 
-        keytitlecompact
-        )
-    return key
+# def autogen_bibtex_key(bibdict):
+#     keytitlecompact = string.join([i[:3] for i in string.split(bibdict['title'].encode("utf-8").translate(string.maketrans("",""), string.punctuation)) if len(i) > 3], '') #ouch ... this compacts the first three letters of each word in the title together, to make a dependably unique key
+#     keyauthorcompact = string.join([i[:1] for i in string.split(bibdict['author'].encode("utf-8").translate(string.maketrans("",""), string.punctuation)) if len(i) > 3], '') #same for authors, but just initials
+#     key = "%s%s_%s" % (
+#         keyauthorcompact,
+#         bibdict['year'].encode('utf-8'), 
+#         keytitlecompact
+#         )
+#     return key
 
-def format_bibtex_entry(bibdict):
-    '''format a single bibtex entry'''
-    if bibdict.has_key('bibtex_key'):
-        key = bibdict['bibtex_key']
-    else:
-        key = autogen_bibtex_key(bibdict)
-    ent = """
-@Misc{%s,
-  author = {%s},
-  title = {%s},
-  howpublished = {%s},
-  month = {%s},
-  year = %s,
-  annote = {%s}}
+# def increment_bibtex_key(keytext):
+#      '''add digits to end of key to try to avoid identical keys'''
+#      try:
+#           last_digit = int(keytext[-1])
+#           if last_digit == 9:
+#                key_base = keytext
+#                last_digit = 0
+#           else:
+#                key_base = keytext[:-1]
+#      except:
+#           last_digit = 0 
+#           key_base = keytext
+#           last_digit += 1
+#      return '%s%d' % (key_base, last_digit)
 
-""" % (
-        key,
-        bibdict['author'].encode('utf-8'),
-        bibdict['title'].encode('utf-8'),
-        bibdict['howpublished'].encode('utf-8'),
-        bibdict['month'].encode('utf-8'),
-        bibdict['year'].encode('utf-8'),
-        bibdict['annote'].encode('utf-8')
-        )
-    return ent
+# def format_bibtex_entry(bibdict):
+#     '''format a single bibtex entry'''
+#     if bibdict.has_key('bibtex_key'):
+#         key = bibdict['bibtex_key']
+#     else:
+#         key = autogen_bibtex_key(bibdict)
+#     ent = """
+# @Misc{%s,
+#   author = {%s},
+#   title = {%s},
+#   howpublished = {%s},
+#   month = {%s},
+#   year = %s,
+#   annote = {%s}}
+
+# """ % (
+#         key,
+#         bibdict['author'].encode('utf-8'),
+#         bibdict['title'].encode('utf-8'),
+#         bibdict['howpublished'].encode('utf-8'),
+#         bibdict['month'].encode('utf-8'),
+#         bibdict['year'].encode('utf-8'),
+#         bibdict['annote'].encode('utf-8')
+#         )
+#     return ent
 
 
 def prefetch_page_info(notify_window, url):
